## 股票账户开户数据（旧）

接口：stk_account_old

描述：获取股票账户开户数据旧版格式数据，数据从2008年1月开始，到2015年5月29，新数据请通过股票开户数据获取。

积分：600积分可调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 统计周期 |
| new_sh | int | Y | 本周新增（上海，户） |
| new_sz | int | Y | 本周新增（深圳，户） |
| active_sh | float | Y | 期末有效账户（上海，万户） |
| active_sz | float | Y | 期末有效账户（深圳，万户） |
| total_sh | float | Y | 期末账户数（上海，万户） |
| total_sz | float | Y | 期末账户数（深圳，万户） |
| trade_sh | float | Y | 参与交易账户数（上海，万户） |
| trade_sz | float | Y | 参与交易账户数（深圳，万户） |

接口使用

```python
pro = ts.pro_api()

df = pro.stk_account_old(start_date='20140101', end_date='20141231')
```

数据示例

```python
date   new_sh  new_sz  active_sh  active_sz  total_sh  total_sz  \
0   20141229~0102  157871  152943    7187.12    7027.58   9269.40   9131.77   
```